@@ -6,11 +6,11 @@ from concurrent.futures import ThreadPoolExecutor, wait
 from . import util, git_util, logs
 from .storage_handler import StorageHandler
 from .auth import get_auth
-from .tartifact_store import TartifactStore
 from .artifact import Artifact
 from .experiment import Experiment, experiment_from_dict
 from .model_setup import get_model_verbose_level
-from .util import retry, report_fatal, compression_to_extension
+from .util import retry, report_fatal,\
+    compression_to_extension, check_for_kb_interrupt
 
 
 class KeyValueProvider(object):
@@ -22,24 +22,23 @@ class KeyValueProvider(object):
             handler: StorageHandler,
             blocking_auth=True,
             compression=None):
-        guest = db_config.get('guest')
+        guest = db_config.get('guest', None)
 
         self.logger = logs.getLogger(self.__class__.__name__)
         self.logger.setLevel(get_model_verbose_level())
 
         self.compression = compression
         if self.compression is None:
-            self.compression = db_config.get('compression')
+            self.compression = db_config.get('compression', None)
 
         self.auth = None
         if not guest and 'serviceAccount' not in db_config.keys():
             self.auth = get_auth(
-                db_config['authentication'],
+                db_config.get('authentication', None),
                 blocking_auth
             )
 
         self.storage_handler = handler
-        self.store = TartifactStore(self.storage_handler, self.logger)
 
         if self.auth and not self.auth.is_expired():
             self.register_user(None, self.auth.get_user_email())
@@ -118,12 +117,13 @@ class KeyValueProvider(object):
         self._set(self._get_experiments_keybase() + experiment.key,
                   experiment_dict)
 
-        self._set(self._get_user_keybase(userid) + "experiments/" +
+        if not experiment.from_compl_service:
+            self._set(self._get_user_keybase(userid) + "experiments/" +
                   experiment.key,
                   experiment.time_added)
 
-        if experiment.project and userid:
-            self._set(self._get_projects_keybase() +
+            if experiment.project and userid:
+                self._set(self._get_projects_keybase() +
                       experiment.project + "/" +
                       experiment.key + "/owner",
                       userid)
@@ -195,6 +195,7 @@ class KeyValueProvider(object):
                 experiment = self.get_experiment(experiment)
                 experiment_key = experiment.key
             except BaseException:
+                check_for_kb_interrupt()
                 experiment = None
         else:
             experiment_key = experiment.key
@@ -206,8 +207,9 @@ class KeyValueProvider(object):
                               .format(experiment_key))
             return
 
+        from_compl_service: bool = experiment_dict.get('from_compl_service', False)
         experiment_owner = experiment_dict.get('owner')
-        if experiment_owner is not None:
+        if experiment_owner is not None and not from_compl_service:
             self._delete(self._get_user_keybase(experiment_owner) +
                      'experiments/' + experiment_key, shallow=False)
 
@@ -219,7 +221,7 @@ class KeyValueProvider(object):
                          'artifact key {1}').format(tag, art.key))
                     art.delete()
 
-            if experiment.project is not None:
+            if experiment.project is not None and not from_compl_service:
                 self._delete(
                     self._get_projects_keybase() +
                     experiment.project + "/" + experiment_key + "/" + "owner",
@@ -227,6 +229,12 @@ class KeyValueProvider(object):
 
         self._delete(self._get_experiments_keybase() + experiment_key, shallow=False)
 
+
+    def cleanup(self):
+        if self.storage_handler is not None:
+            self.storage_handler.cleanup()
+
+
     def checkpoint_experiment(self, experiment, blocking=False):
         key = self._experiment_key(experiment)
         key_path = self._get_experiments_keybase() + key
@@ -239,7 +247,7 @@ class KeyValueProvider(object):
         with ThreadPoolExecutor(max_workers=8) as executor:
             for _, art in experiment.artifacts.items():
                 if art.is_mutable and art.local_path is not None:
-                    workers.append(executor.submit(self.store.put_artifact, art))
+                    workers.append(executor.submit(art.upload, None))
             wait(workers)
 
         for worker in workers:
@@ -270,7 +278,8 @@ class KeyValueProvider(object):
             metric_name = metric_str[0]
             metric_type = metric_str[1] if len(metric_str) > 1 else None
 
-            tbtar = self.store.stream_artifact(experiment.artifacts['tb'])
+            tb_art = experiment.artifacts['tb']
+            tbtar = tb_art.stream() if tb_art else None
 
             if metric_type == 'min':
                 def metric_accum(x, y): return min(x, y) if x else y
@@ -280,13 +289,14 @@ class KeyValueProvider(object):
                 def metric_accum(x, y): return y
 
             metric_value = None
-            for f in tbtar:
-                if f.isreg():
-                    for e in util.event_reader(tbtar.extractfile(f)):
-                        for v in e.summary.value:
-                            if v.tag == metric_name:
-                                metric_value = metric_accum(
-                                    metric_value, v.simple_value)
+            if tbtar is not None:
+                for f in tbtar:
+                    if f.isreg():
+                        for e in util.event_reader(tbtar.extractfile(f)):
+                            for v in e.summary.value:
+                                if v.tag == metric_name:
+                                    metric_value = metric_accum(
+                                        metric_value, v.simple_value)
 
             info['metric_value'] = metric_value
 
@@ -294,7 +304,7 @@ class KeyValueProvider(object):
 
     def _get_experiment_logtail(self, experiment: Experiment):
         try:
-            tarf = self.store.stream_artifact(experiment.artifacts['output'])
+            tarf = experiment.artifacts['output'].stream()
             if not tarf:
                 return None
             tarf_member = tarf.members[0]
@@ -307,6 +317,7 @@ class KeyValueProvider(object):
         except BaseException as e:
             self.logger.debug('Getting experiment logtail raised an exception: {0}'
                               .format(repr(e)))
+            check_for_kb_interrupt()
             return None
 
     def get_experiment(self, key, getinfo=True) -> Experiment:
@@ -368,9 +379,9 @@ class KeyValueProvider(object):
         return retval
 
     def get_artifact(self, artifact, local_path=None, only_newer=True):
-        return self.store.get_artifact(artifact,
-                                       local_path=local_path,
-                                       only_newer=only_newer)
+        return artifact.download(
+            local_path=local_path,
+            only_newer=only_newer)
 
     def get_projects(self):
         return self._get(self._get_projects_keybase(), shallow=True)
@@ -417,11 +428,12 @@ class KeyValueProvider(object):
         if existing_email != email:
             self._set(keypath, email)
 
-    def get_artifact_store(self):
-        return self.store
+    def get_storage_handler(self):
+        return self.storage_handler
 
     def __enter__(self):
         return self
 
     def __exit__(self, *args):
-        pass
\ No newline at end of file
+        pass
+
