@@ -14,13 +14,13 @@ from apscheduler.schedulers.background import BackgroundScheduler
 from . import fs_tracker, model, logs
 from .local_queue import LocalQueue
 from .gpu_util import get_available_gpus, get_gpu_mapping, get_gpus_summary
+from .artifact import Artifact
 from .experiment import Experiment
-from .util import sixdecode, str2duration, retry, LogReprinter
-from .model import parse_verbosity
+from .util import sixdecode, str2duration, retry,\
+    parse_verbosity, check_for_kb_interrupt
 
 logs.getLogger('apscheduler.scheduler').setLevel(logs.ERROR)
 
-
 class LocalExecutor(object):
     """Runs job while capturing environment and logs results.
     """
@@ -62,8 +62,6 @@ class LocalExecutor(object):
             fs_tracker.setup_experiment(env, experiment, clean=False)
             log_path = fs_tracker.get_artifact_cache('output', experiment.key)
 
-            # log_path = os.path.join(model_dir, self.config['log']['name'])
-
             self.logger.debug('Child process environment:')
             self.logger.debug(str(env))
 
@@ -78,7 +76,7 @@ class LocalExecutor(object):
                 python = which(python)
 
                 cmd = [python, experiment.filename] + experiment.args
-                cwd = experiment.artifacts['workspace']['local']
+                cwd = experiment.artifacts['workspace'].local_path
                 container_artifact = experiment.artifacts.get('_singularity')
                 if container_artifact:
                     container = container_artifact.get('local')
@@ -109,53 +107,36 @@ class LocalExecutor(object):
 
                 p = subprocess.Popen(
                     cmd,
-                    stdout=output_file,
+                    stdout=subprocess.PIPE,
                     stderr=subprocess.STDOUT,
                     env=env,
-                    cwd=cwd
+                    cwd=cwd,
+                    text=True
                 )
 
-                run_log_reprinter = True
-                log_reprinter = LogReprinter(log_path)
-                if run_log_reprinter:
-                    log_reprinter.run()
-
                 def kill_subprocess():
-                    log_reprinter.stop()
                     p.kill()
 
-                minutes = 0
-                if self.config.get('saveWorkspaceFrequency'):
-                    minutes = int(
-                        str2duration(
-                            self.config['saveWorkspaceFrequency'])
-                        .total_seconds() / 60)
+                def get_duration(tag: str):
+                    value = self.config.get(tag, '0m')
+                    return int(str2duration(value).total_seconds() / 60)
 
                 def checkpoint():
                     try:
                         db.checkpoint_experiment(experiment)
                     except BaseException as e:
                         self.logger.info(e)
+                        check_for_kb_interrupt()
 
-                sched.add_job(
-                    checkpoint,
-                    'interval',
-                    minutes=minutes)
+                minutes = get_duration('saveWorkspaceFrequency')
+                sched.add_job(checkpoint, 'interval', minutes=minutes)
 
                 metrics_path = fs_tracker.get_artifact_cache(
                     '_metrics', experiment.key)
 
-                minutes = 0
-                if self.config.get('saveMetricsFrequency'):
-                    minutes = int(
-                        str2duration(
-                            self.config['saveMetricsFrequency'])
-                        .total_seconds() / 60)
-
-                sched.add_job(
-                    lambda: save_metrics(metrics_path),
-                    'interval',
-                    minutes=minutes)
+                minutes = get_duration('saveMetricsFrequency')
+                sched.add_job(lambda: save_metrics(metrics_path),
+                              'interval', minutes=minutes)
 
                 def kill_if_stopped():
                     try:
@@ -163,6 +144,7 @@ class LocalExecutor(object):
                             experiment.key,
                             getinfo=False)
                     except:
+                        check_for_kb_interrupt()
                         db_expr = None
 
                     # Transient issues with getting experiment data might
@@ -192,17 +174,24 @@ class LocalExecutor(object):
 
                 sched.add_job(kill_if_stopped, 'interval', seconds=10)
 
+                while True:
+                    output = p.stdout.readline()
+                    if output == '' and p.poll() is not None:
+                        break
+                    if output:
+                        line_out = output.strip()
+                        print(line_out)
+                        output_file.write(line_out)
+
                 try:
                     p.wait()
                 finally:
-                    log_reprinter.stop()
                     save_metrics(metrics_path)
                     sched.shutdown()
                     db.checkpoint_experiment(experiment)
                     db.finish_experiment(experiment)
                     return p.returncode
 
-
 def allocate_resources(experiment, config=None, verbose=10):
     logger = logs.getLogger('allocate_resources')
     logger.setLevel(verbose)
@@ -272,6 +261,12 @@ def main(args=sys.argv):
     parsed_args, script_args = parser.parse_known_args(args)
     verbose = parse_verbosity(parsed_args.verbose)
 
+    # worker_config = None
+    # if parsed_args.config is not None:
+    #     print("Local Runner configuration file = {0}".format(parsed_args.config))
+    #     with open(parsed_args.config) as f:
+    #         worker_config = json.load(f)
+
     queue = LocalQueue(verbose=verbose)
     # queue = glob.glob(fs_tracker.get_queue_directory() + "/*")
     # wait_for_messages(queue, parsed_args.timeout)
@@ -389,21 +384,23 @@ def worker_loop(queue, parsed_args,
                                 for pkg in pip_diff:
                                     pip_install_packages([pkg], python, logger)
 
-                    for tag, art in six.iteritems(experiment.artifacts):
-                        if fetch_artifacts or 'local' not in art.keys():
-                            logger.info('Fetching artifact ' + tag)
+                    for tag, item in experiment.artifacts.items():
+                        art: Artifact = item
+                        if fetch_artifacts or art.local_path is None:
+                            get_only_newer: bool = True
                             if tag == 'workspace':
-                                art['local'] = retry(lambda: db.get_artifact(
-                                    art,
-                                    only_newer=False),
-                                    sleep_time=10,
-                                    logger=logger)
-                            else:
-                                art['local'] = retry(
-                                    lambda: db.get_artifact(art),
+                                get_only_newer = False
+
+                            if not art.is_mutable:
+                                logger.info('Fetching artifact ' + tag)
+                                art.local_path = retry(
+                                    lambda: db.get_artifact(art, only_newer=get_only_newer),
                                     sleep_time=10,
                                     logger=logger
                                 )
+                            else:
+                                logger.info('Skipping mutable artifact ' + tag)
+
 
                     returncode = executor.run(experiment)
                     if returncode != 0:
