@@ -2,11 +2,11 @@
 
 import pika
 import time
-import logging
 import threading
 
-from . import logs
+from .model_setup import get_model_verbose_level
 
+from . import logs
 
 class RMQueue(object):
     """This publisher will handle failures and closures and will
@@ -18,7 +18,7 @@ class RMQueue(object):
     """
 
     def __init__(self, queue, route, amqp_url='',
-                 config=None, logger=None, verbose=None):
+                 config=None, logger=None):
         """Setup the example publisher object, passing in the URL we will use
         to connect to RabbitMQ.
         """
@@ -43,12 +43,13 @@ class RMQueue(object):
         self._routing_key = route
 
         self._url = amqp_url
+        self._is_persistent: bool = False
 
         if logger is not None:
             self._logger = logger
         else:
             self._logger = logs.getLogger('RabbitMQ')
-            self._logger.setLevel(logging.INFO)
+            self._logger.setLevel(get_model_verbose_level())
 
         if config is not None:
             # extract from the config data structure any settings related to
@@ -57,8 +58,13 @@ class RMQueue(object):
                 if 'queue' in config['cloud']:
                     if 'rmq' in config['cloud']['queue']:
                         self._url = config['cloud']['queue']['rmq']
-                        self._logger.warn('url {}'
-                                          .format(self._url))
+                        self._logger.warning('use queue url {}'
+                                             .format(self._url))
+                        flag_persistent = config['cloud']['queue']\
+                            .get('persistent', False)
+                        if isinstance(flag_persistent, str):
+                            flag_persistent = flag_persistent.lower() == 'true'
+                        self._is_persistent = flag_persistent
 
         self._queue = queue
         self._queue_deleted = True
@@ -117,7 +123,7 @@ class RMQueue(object):
 
     def _wait_queue_created(self, timeout_in_secs):
         """
-        Polling wait till underlying RMQ queue
+        Polling wait till underlying   queue
         is confirmed created.
         If specified timeout (in seconds) is reached,
         exception is raised.
@@ -302,7 +308,9 @@ class RMQueue(object):
         """
         self._logger.debug('declare queue ' + queue_name)
         with self._rmq_lock:
-            self._channel.queue_declare(queue_name, callback=self.on_queue_declareok)
+            self._channel.queue_declare(queue_name,
+                                        durable=self._is_persistent,
+                                        callback=self.on_queue_declareok)
 
     def on_queue_declareok(self, method_frame):
         """
@@ -441,7 +449,7 @@ class RMQueue(object):
     def clean(self, timeout=0):
         while True:
             msg = self.dequeue(timeout=timeout)
-            if not msg:
+            if msg is None:
                 break
         return
 
@@ -491,8 +499,15 @@ class RMQueue(object):
 
         self._logger.debug('sending message {} to {} '
                            .format(msg, self._url))
-        properties = pika.BasicProperties(app_id='studioml',
-                                          content_type='application/json')
+        if self._is_persistent:
+            properties = pika.BasicProperties(
+                app_id='studioml',
+                delivery_mode=2,  # make message persistent
+                content_type='application/json')
+        else:
+            properties = pika.BasicProperties(
+                app_id='studioml',
+                content_type='application/json')
 
         self._channel.basic_publish(exchange=self._exchange,
                                     routing_key=self._routing_key,
@@ -542,18 +557,23 @@ class RMQueue(object):
                 if self._rmq_msg is not None:
                     self._logger.info('message {0} from {1} '
                                       .format(self._rmq_msg, self._url))
-                    return self._rmq_msg, self._rmq_id
+                    rec_msg = self._rmq_msg
+                    rec_id = self._rmq_id
+                    if acknowledge:
+                        self.acknowledge(self._rmq_id)
+                    return rec_msg, rec_id
                 else:
                     self._logger.info('idle {0} {1}'
                                       .format(self._url, self._queue))
 
             if i >= timeout:
-                self._logger.info('timed-out')
+                self._logger.info('timed-out trying to dequeue from {0}'
+                                  .format(self._url))
                 return None
 
             time.sleep(1)
 
-        self._logger.info('dequeue done')
+        self._logger.debug('dequeue done from {0}'.format(self._url))
 
     def on_message(self, unused_channel, basic_deliver, properties, body):
 
@@ -561,8 +581,7 @@ class RMQueue(object):
             if self._channel is not None:
                 # Cancel the consumer as we only consume 1 message
                 # at a time
-                self._channel.basic_cancel(
-                    nowait=True, consumer_tag=self._consumer)
+                self._channel.basic_cancel(consumer_tag=self._consumer)
             self._consumer = None
 
             # If we already had a delivered message, reject the one we just got
@@ -585,6 +604,7 @@ class RMQueue(object):
             if self._channel is None:
                 return None
             result = self._channel.basic_ack(delivery_tag=ack_id)
+            return result
 
     def hold(self, ack_id, minutes):
         # Nothing is needed here as the message will remain while the channel
