@@ -1,3 +1,4 @@
+import copy
 import sys
 import argparse
 import re
@@ -8,10 +9,9 @@ import time
 import six
 import numpy as np
 
-from datetime import timedelta
-
+from .credentials import KEY_CREDENTIALS
 from .hyperparameter import HyperparameterParser
-from .util import rand_string, Progbar, rsync_cp
+from .util import rand_string, Progbar, rsync_cp, check_for_kb_interrupt
 from .experiment import create_experiment
 from .experiment_submitter import submit_experiments
 from . import model
@@ -268,12 +268,48 @@ def main(args=sys.argv[1:]):
     logger.debug('resources requested: ')
     logger.debug(str(resources_needed))
 
-    artifacts = {}
+    # Set up default artifacts:
+    artifacts = {
+        'workspace': {
+            'mutable': False,
+            'local': os.getcwd(),
+            'unpack': True
+        },
+        'modeldir': {
+            'mutable': True,
+            'unpack': True
+        },
+        'retval': {
+            'mutable': True,
+            'unpack': True
+        },
+        'output': {
+            'mutable': True,
+            'unpack': True
+        },
+        'tb': {
+            'mutable': True,
+            'unpack': True
+        },
+        '_metrics': {
+            'mutable': True,
+            'unpack': True
+        },
+        '_metadata': {
+            'mutable': True,
+            'unpack': True
+        }
+    }
+
     artifacts.update(_parse_artifacts(runner_args.capture, mutable=True))
     artifacts.update(_parse_artifacts(runner_args.capture_once, mutable=False))
     with model.get_db_provider(config) as db:
         artifacts.update(_parse_external_artifacts(runner_args.reuse, db))
 
+    logger.debug("Task artifacts: %s", repr(artifacts))
+    storage_creds = config.get('storage', {}).get(KEY_CREDENTIALS, None)
+    _setup_artifacts_creds(artifacts, storage_creds)
+
     if runner_args.branch:
         config['cloud']['branch'] = runner_args.branch
 
@@ -385,11 +421,13 @@ def main(args=sys.argv[1:]):
                 try:
                     optimizer.tell(hyperparam_pop, fitnesses, behaviors)
                 except BaseException:
+                    check_for_kb_interrupt()
                     optimizer.tell(hyperparam_pop, fitnesses)
 
                 try:
                     optimizer.disp()
                 except BaseException:
+                    check_for_kb_interrupt()
                     logger.warn('Optimizer has no disp() method')
     else:
         if rerun:
@@ -532,10 +570,6 @@ def get_experiment_fitnesses(experiments, optimizer, config, logger):
                     continue
                 returned_experiment = db.get_experiment(experiment.key,
                                                         getinfo=True)
-                # try:
-                #     experiment_output = returned_experiment.info['logtail']
-                # except BaseException:
-                #     logger.warn('Cannot access "logtail" in experiment.info')
                 output = db._get_experiment_logtail(
                     returned_experiment)
                 if output is None:
@@ -564,6 +598,7 @@ def get_experiment_fitnesses(experiments, optimizer, config, logger):
                                 raise
 
                         except BaseException:
+                            check_for_kb_interrupt()
                             if j not in bad_line_dicts[i]:
                                 logger.warn(
                                     'Experiment %s: error parsing or invalid'
@@ -580,6 +615,7 @@ def get_experiment_fitnesses(experiments, optimizer, config, logger):
                             fitness = float(line.rstrip().split(':')[1])
                             # assert fitness >= 0.0
                         except BaseException:
+                            check_for_kb_interrupt()
                             if j not in bad_line_dicts[i]:
                                 logger.warn(
                                     'Experiment %s: error parsing or invalid'
@@ -664,6 +700,10 @@ def _parse_external_artifacts(art_list, db):
         }
     return retval
 
+def _setup_artifacts_creds(artifacts, storage_creds):
+    for tag, art_dict in artifacts.items():
+        if 'local' in art_dict.keys():
+            art_dict[KEY_CREDENTIALS] = copy.deepcopy(storage_creds)
 
 def _parse_hardware(runner_args, config={}):
     resources_needed = {}
