@@ -1,11 +1,12 @@
 import tensorflow as tf
 
-
-sess = tf.Session()
 a = tf.constant([1.0, 5.0])
-b = a + 1.0
 
-result = sess.run(b)
+@tf.function
+def forward(x):
+  return x + 1.0
+
+result = forward(a)
 assert len(result) == 2
 
 print("[ {} {} ]".format(result[0], result[1]))
